aboutsummaryrefslogtreecommitdiffstats
path: root/mousefunc.c
diff options
context:
space:
mode:
authorokan2011-05-05 19:52:52 +0000
committerokan2011-05-05 19:52:52 +0000
commit720369b4d14995ba9c098117ddfd4e0372bb6a73 (patch)
treeed1f8319b56806c864d7a1e64ceef26e88b99097 /mousefunc.c
parenta881ee3794d3599400f557e675f2562b862b63f0 (diff)
downloadcwm-720369b4d14995ba9c098117ddfd4e0372bb6a73.tar.gz
bump window resize back to 60hz. instead, we should not need to sync
every time we move/resize a window, so remove XSync in both mouse move and resize events. tested by Brynet as well. ok oga@
Diffstat (limited to '')
-rw-r--r--mousefunc.c10
1 files changed, 4 insertions, 6 deletions
diff --git a/mousefunc.c b/mousefunc.c
index 5a67276..9b55c6d 100644
--- a/mousefunc.c
+++ b/mousefunc.c
@@ -16,7 +16,7 @@
* ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
* OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*
- * $Id: mousefunc.c,v 1.22 2011/03/23 07:27:32 okan Exp $
+ * $Id: mousefunc.c,v 1.23 2011/05/05 19:52:52 okan Exp $
*/
#include <sys/param.h>
@@ -106,10 +106,9 @@ mousefunc_window_resize(struct client_ctx *cc, void *arg)
/* Recompute window output */
mousefunc_sweep_draw(cc);
- /* don't sync more than 10 times / second */
- if ((ev.xmotion.time - time) > (1000 / 10)) {
+ /* don't resize more than 60 times / second */
+ if ((ev.xmotion.time - time) > (1000 / 60)) {
time = ev.xmotion.time;
- XSync(X_Dpy, False);
client_resize(cc);
}
break;
@@ -159,10 +158,9 @@ mousefunc_window_move(struct client_ctx *cc, void *arg)
cc->geom.x = ev.xmotion.x_root - px - cc->bwidth;
cc->geom.y = ev.xmotion.y_root - py - cc->bwidth;
- /* don't sync more than 60 times / second */
+ /* don't move more than 60 times / second */
if ((ev.xmotion.time - time) > (1000 / 60)) {
time = ev.xmotion.time;
- XSync(X_Dpy, False);
client_move(cc);
}
break;